# The AIConsole Project
#
# Copyright 2023 10Clouds
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
    
from pathlib import Path
from aiconsole.consts import AICONSOLE_PATH


def resource_to_path(resource) -> Path:
    abs_path = AICONSOLE_PATH.parent

    for path_segment in resource.split("."):
        abs_path = abs_path / path_segment

    return abs_path


# The AIConsole Project
#
# Copyright 2023 10Clouds
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from fastapi import APIRouter
from starlette.responses import JSONResponse

from aiconsole.core.settings.project_settings import PartialSettingsAndToGlobal, get_aiconsole_settings

router = APIRouter()


@router.patch("")
async def patch(patch_data: PartialSettingsAndToGlobal):
    get_aiconsole_settings().save(settings_data=patch_data, to_global=patch_data.to_global)
    return JSONResponse({"status": "ok"})


@router.get("")
async def get():
    return JSONResponse(get_aiconsole_settings().model_dump())



import logging
import subprocess
import sys
from pathlib import Path

from aiconsole.consts import AICONSOLE_PATH, AICONSOLE_ROOT_PACKAGE_PATH

logger = logging.getLogger(__name__)


async def create_dedicated_venv():
    venv_path = get_current_project_venv_path()
    if not venv_path.exists():
        # should create the .venv for the first time in the current project directory
        subprocess.Popen([sys.executable, "-m", "venv", venv_path], stdout=subprocess.PIPE,
                         stderr=subprocess.PIPE).communicate()

    try:
        subprocess.check_call([str(venv_path / "bin" / "pip"), "install", AICONSOLE_ROOT_PACKAGE_PATH])
    except subprocess.CalledProcessError as e:
        logger.error(f"Could not install aiconsole in venv {e}")


def get_current_project_venv_path():
    return Path.cwd() / ".venv"


def get_current_project_venv_python_path():
    return get_current_project_venv_path() / "bin" / "python"


def get_current_project_venv_available_packages():
    venv_path = get_current_project_venv_path()
    try:
        output = subprocess.check_output([str(venv_path / "bin" / "pip"), "list"]).decode('utf-8')
        package_lines = output.split('\\n')
        package_names = [line.split("==")[0] for line in package_lines]
        return ' '.join(package_names)
    except subprocess.CalledProcessError:
        return ''
